Name:           cloud-init
Version:        20.2
%define subrel 1
Release:        %mkrel 2
Summary:        Cloud instance init scripts

Group:          Networking/Other
License:        ASL 2.0 or GPLv3
URL:            https://github.com/canonical/cloud-init
Source0:        https://github.com/canonical/cloud-init/archive/%{version}/%{name}-%{version}.tar.gz
Source1:        cloud-init-mageia.cfg
Source2:        cloud-init-README.mageia
Source3:        mageia.py
Source4:        cloud-init-tmpfiles.conf
Patch0:         cloud-init-20.2-CVE-2021-3429.patch

BuildArch:      noarch

BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  systemd-units
# For tests
BuildRequires:  python3-configobj
# https://bugzilla.redhat.com/show_bug.cgi?id=1695953
BuildRequires:  python3-distro
# https://bugzilla.redhat.com/show_bug.cgi?id=1417029
BuildRequires:  python3-httpretty >= 0.8.14-2
BuildRequires:  python3-jinja2
BuildRequires:  python3-jsonpatch
BuildRequires:  python3-jsonschema
BuildRequires:  python3-mock
BuildRequires:  python3-nose
BuildRequires:  python3-oauthlib
BuildRequires:  python3-prettytable
BuildRequires:  python3-serial
BuildRequires:  python3-PyYAML
BuildRequires:  python3-requests
BuildRequires:  python3-six
Requires:       dmidecode
Requires:       e2fsprogs
Requires:       hostname
Requires:       iproute2
Requires:       python3-libselinux
Requires:       net-tools
Requires:       policycoreutils-python3
Requires:       procps
Requires:       rsyslog
Requires:       shadow-utils
Requires:       xfsprogs
Requires:       run-parts
Requires:       cloud-utils-growpart
Requires(post):   systemd-units
Requires(preun):  systemd-units
Requires(postun): systemd-units

%description
Cloud-init is a set of init scripts for cloud instances.  Cloud instances
need special scripts to run during initialization to retrieve and install
ssh keys and to let the user run various scripts.


%prep
%autosetup -p1

# Change shebangs
sed -i -e 's|#!/usr/bin/env python|#!/usr/bin/env python3|' \
       -e 's|#!/usr/bin/python|#!/usr/bin/python3|' tools/* cloudinit/ssh_util.py

cp -p %{SOURCE2} README.mageia
cp %{SOURCE3} cloudinit/distros

%build
%py3_build


%install
%py3_install -- --init-system=systemd

mkdir -p %{buildroot}%{_sharedstatedir}/cloud

# We supply our own config file since our software differs from Ubuntu's.
cp -p %{SOURCE1} %{buildroot}%{_sysconfdir}/cloud/cloud.cfg

# /run/cloud-init needs a tmpfiles.d entry
mkdir -p %{buildroot}/run/cloud-init
mkdir -p %{buildroot}%{_tmpfilesdir}
cp -p %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

mkdir -p %{buildroot}%{_sysconfdir}/rsyslog.d
cp -p tools/21-cloudinit.conf %{buildroot}%{_sysconfdir}/rsyslog.d/21-cloudinit.conf

%post
%_tmpfilescreate %{name}
if [ $1 -eq 1 ] ; then
    # Initial installation
    # Enabled by default per "runs once then goes away" exception
    /bin/systemctl enable cloud-config.service     >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-final.service      >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init.service       >/dev/null 2>&1 || :
    /bin/systemctl enable cloud-init-local.service >/dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable cloud-config.service >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-final.service  >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init.service   >/dev/null 2>&1 || :
    /bin/systemctl --no-reload disable cloud-init-local.service >/dev/null 2>&1 || :
    # One-shot services -> no need to stop
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
# One-shot services -> no need to restart


%files
%doc ChangeLog TODO.rst README.mageia
%doc doc/*
%license LICENSE
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg
%dir               %{_sysconfdir}/cloud/cloud.cfg.d
%config(noreplace) %{_sysconfdir}/cloud/cloud.cfg.d/*.cfg
%doc               %{_sysconfdir}/cloud/cloud.cfg.d/README
%dir               %{_sysconfdir}/cloud/templates
%config(noreplace) %{_sysconfdir}/cloud/templates/*
%{_sysconfdir}/NetworkManager/dispatcher.d/hook-network-manager
%{_sysconfdir}/dhcp/dhclient-exit-hooks.d/hook-dhclient
/lib/udev/rules.d/66-azure-ephemeral.rules
%{_unitdir}/cloud-config.service
%{_unitdir}/cloud-final.service
%{_unitdir}/cloud-init.service
%{_unitdir}/cloud-init-local.service
%{_unitdir}/cloud-config.target
%{_unitdir}/cloud-init.target
%{_prefix}/lib/systemd/system-generators/cloud-init-generator
%{_tmpfilesdir}/%{name}.conf
%{python3_sitelib}/*
%{_libexecdir}/%{name}
%{_bindir}/cloud-init*
%{_bindir}/cloud-id
%ghost %dir /run/cloud-init
%dir %{_sharedstatedir}/cloud
%{_datadir}/bash-completion/completions/%{name}

%config(noreplace) %{_sysconfdir}/rsyslog.d/21-cloudinit.conf


%changelog
* Wed Jun 02 2021 ns80 <ns80> 20.2-2.1.mga8
+ Revision: 1729192
- add Debian patch for CVE-2021-3429 (mga#28991)

* Sun Jan 31 2021 daviddavid <daviddavid> 20.2-2.mga8
+ Revision: 1674200
- fix selinux python dependency

* Wed Jun 10 2020 joequant <joequant> 20.2-1.mga8
+ Revision: 1591871
- update to 20.2

* Sun May 24 2020 neoclust <neoclust> 19.4-3.mga8
+ Revision: 1587393
- Add P0/P1 to fix security issue (mga#26236)

* Mon Apr 06 2020 tv <tv> 19.4-2.mga8
+ Revision: 1565116
- files in /run must be %%ghost
- fix license
- change shebang
- add missing BRs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- new version 19.4
+ daviddavid <daviddavid>
- new version: 19.2
- port to python 3

* Tue Sep 18 2018 umeabot <umeabot> 0.7.5-7.mga7
+ Revision: 1261459
- Mageia 7 Mass Rebuild

* Wed Feb 03 2016 umeabot <umeabot> 0.7.5-6.mga6
+ Revision: 933841
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.7.5-5.mga5
+ Revision: 744925
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.7.5-4.mga5
+ Revision: 726052
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.7.5-3.mga5
+ Revision: 678432
- Mageia 5 Mass Rebuild

* Tue Sep 09 2014 luigiwalser <luigiwalser> 0.7.5-2.mga5
+ Revision: 673848
- add requires on hostname now that it is in a different package

* Thu Jul 10 2014 joequant <joequant> 0.7.5-1.mga5
+ Revision: 651058
- fix cloud-init require and update to 0.7.5

* Sat May 31 2014 pterjan <pterjan> 0.7.2-8.mga5
+ Revision: 628134
- Rebuild for new Python
+ joequant <joequant>
- add dependency on cloud-utils-growpart

* Wed Nov 27 2013 joequant <joequant> 0.7.2-6.mga4
+ Revision: 553686
- add cloud-init
- add growpart to cloud-init

* Mon Nov 25 2013 joequant <joequant> 0.7.2-5.mga4
+ Revision: 553373
- add mageia cloud init module

* Tue Oct 22 2013 umeabot <umeabot> 0.7.2-4.mga4
+ Revision: 542528
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 pterjan <pterjan> 0.7.2-3.mga4
+ Revision: 497674
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 23 2013 joequant <joequant> 0.7.2-2.mga4
+ Revision: 483775
- fix requires to be consistent with mageia

* Sun Sep 22 2013 joequant <joequant> 0.7.2-1.mga4
+ Revision: 483137
- imported package cloud-init

